==> lxqt-panel-2.3.0.tar.xz: lxqt-panel-2.3.0/plugin-customcommand/translations/customcommand_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>ColorLabel</name>
    <message>
        <location filename="../colorLabel.cpp" line="36"/>
        <source>Click to change color</source>
        <translation>Klicka för att ändra färg</translation>
    </message>
    <message>
        <location filename="../colorLabel.cpp" line="65"/>
        <source>Select Color</source>
        <translation>Välj färg</translation>
    </message>
</context>
<context>
    <name>LXQtCustomCommandConfiguration</name>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="14"/>
        <source>Custom Command Configuration</source>
        <translation>Konfigurering av egendefinierade kommandon</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="20"/>
        <source>Display</source>
        <translation>Visa</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="303"/>
        <source>Use icon from theme or browse file</source>
        <translation>Använd ikon från tema eller bläddra efter fil</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="97"/>
        <source>Run with &quot;bash -c&quot;</source>
        <translation>Kör med &quot;bash -c&quot;</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="107"/>
        <source>Select Font</source>
        <translation>Välj typsnitt</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="280"/>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="68"/>
        <source>Command</source>
        <translation>Kommando</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="166"/>
        <source>Font</source>
        <translation>Typsnitt</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="78"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="263"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="266"/>
        <source>Use %1 to display command output</source>
        <translation>Använd %1 för att visa utdata från kommando</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="173"/>
        <source>Icon</source>
        <translation>Ikon</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="293"/>
        <source>Browse</source>
        <translation>Bläddra</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="159"/>
        <source>Autorotate when the panel is vertical</source>
        <translation>Rotera automatiskt när panelen är vertikal</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="43"/>
        <source>Output format:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="50"/>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="136"/>
        <source>echo Configure...</source>
        <translation>echo konfigurera...</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="142"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="341"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="358"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="375"/>
        <source>Command to run</source>
        <translation>Kommando att köra</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="149"/>
        <source>Max Width</source>
        <translation>Max bredd</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="225"/>
        <source>Repeat command after:</source>
        <translation>Repetera kommando efter:</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="117"/>
        <source>Text Color</source>
        <translation>Textfärg</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="28"/>
        <source>Reset</source>
        <translation>Återställ</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="241"/>
        <source> second(s)</source>
        <translation> sekund(er)</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="273"/>
        <source>Tooltip</source>
        <translation>Verktygsfält</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="310"/>
        <source>Continuous output (processed line by line)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="325"/>
        <source>Mouse Commands</source>
        <translation>Muskommandon</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="331"/>
        <source>Click</source>
        <translation>Klick</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="348"/>
        <source>Wheel Up</source>
        <translation>Hjul upp</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="365"/>
        <source>Wheel Down</source>
        <translation>Hjul ner</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="37"/>
        <source>command outputs plain text to be used as text of the button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="38"/>
        <source>command outputs icon in form of:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="39"/>
        <source>theme name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="40"/>
        <source>name of icon resolved to image based on XDG spec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="41"/>
        <source>image file path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="42"/>
        <source>image data stream</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="43"/>
        <source>plain image stream</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="44"/>
        <source>base64 encoded image data stream</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="45"/>
        <source>as above but base64 encoded</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="46"/>
        <source>command outputs structured variables to be used for button visualization in form of:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="47"/>
        <source>name1:base64value1 name2:base64value2  ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="48"/>
        <source>Handled names are:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="49"/>
        <source>string to be used as text of the button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="50"/>
        <source>icon to be shown in the button, in the same form as explained before</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="51"/>
        <source>string to be used as tooltip of the button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="52"/>
        <source>All values should be encoded in base64</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="53"/>
        <source>Example of script generating structured output:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="54"/>
        <source>My Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="55"/>
        <source>my_image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="56"/>
        <source>My Tooltip</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="63"/>
        <source>Text only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="64"/>
        <source>Icon only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="65"/>
        <source>Structured</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="268"/>
        <source>Select Icon File</source>
        <translation>Välj ikonfil</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="268"/>
        <source>Images (*.png *.svg *.xpm *.jpg)</source>
        <translation>Bilder (*.png *.svg *.xpm *.jpg)</translation>
    </message>
</context>
</TS>

==> lxqt-panel-2.3.2.tar.xz: lxqt-panel-2.3.2/plugin-customcommand/translations/customcommand_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>ColorLabel</name>
    <message>
        <location filename="../colorLabel.cpp" line="36"/>
        <source>Click to change color</source>
        <translation>Klicka för att ändra färg</translation>
    </message>
    <message>
        <location filename="../colorLabel.cpp" line="65"/>
        <source>Select Color</source>
        <translation>Välj färg</translation>
    </message>
</context>
<context>
    <name>LXQtCustomCommandConfiguration</name>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="14"/>
        <source>Custom Command Configuration</source>
        <translation>Konfigurering av egendefinierade kommandon</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="20"/>
        <source>Display</source>
        <translation>Visa</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="303"/>
        <source>Use icon from theme or browse file</source>
        <translation>Använd ikon från tema eller bläddra efter fil</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="97"/>
        <source>Run with &quot;bash -c&quot;</source>
        <translation>Kör med &quot;bash -c&quot;</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="107"/>
        <source>Select Font</source>
        <translation>Välj typsnitt</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="280"/>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="68"/>
        <source>Command</source>
        <translation>Kommando</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="166"/>
        <source>Font</source>
        <translation>Typsnitt</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="78"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="263"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="266"/>
        <source>Use %1 to display command output</source>
        <translation>Använd %1 för att visa utdata från kommando</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="173"/>
        <source>Icon</source>
        <translation>Ikon</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="293"/>
        <source>Browse</source>
        <translation>Bläddra</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="159"/>
        <source>Autorotate when the panel is vertical</source>
        <translation>Rotera automatiskt när panelen är vertikal</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="43"/>
        <source>Output format:</source>
        <translation>Utdataformat:</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="50"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="136"/>
        <source>echo Configure...</source>
        <translation>echo konfigurera...</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="142"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="341"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="358"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="375"/>
        <source>Command to run</source>
        <translation>Kommando att köra</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="149"/>
        <source>Max Width</source>
        <translation>Max bredd</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="225"/>
        <source>Repeat command after:</source>
        <translation>Repetera kommando efter:</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="117"/>
        <source>Text Color</source>
        <translation>Textfärg</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="28"/>
        <source>Reset</source>
        <translation>Återställ</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="241"/>
        <source> second(s)</source>
        <translation> sekund(er)</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="273"/>
        <source>Tooltip</source>
        <translation>Verktygsfält</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="310"/>
        <source>Continuous output (processed line by line)</source>
        <translation>Kontinuerlig utdata (bearbetad rad för rad)</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="325"/>
        <source>Mouse Commands</source>
        <translation>Muskommandon</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="331"/>
        <source>Click</source>
        <translation>Klick</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="348"/>
        <source>Wheel Up</source>
        <translation>Hjul upp</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="365"/>
        <source>Wheel Down</source>
        <translation>Hjul ner</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="37"/>
        <source>command outputs plain text to be used as text of the button</source>
        <translation>kommandot matar ut vanlig text som ska användas som text på knappen</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="38"/>
        <source>command outputs icon in form of:</source>
        <translation>kommandoutmatning ikon i form av:</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="39"/>
        <source>theme name</source>
        <translation>temanamn</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="40"/>
        <source>name of icon resolved to image based on XDG spec</source>
        <translation>namn på ikonen som lösts till bild baserat på XDG-specifikationen</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="41"/>
        <source>image file path</source>
        <translation>bild filsökväg</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="42"/>
        <source>image data stream</source>
        <translation>bilddataström</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="43"/>
        <source>plain image stream</source>
        <translation>vanlig bildström</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="44"/>
        <source>base64 encoded image data stream</source>
        <translation>base64 kodad bilddataström</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="45"/>
        <source>as above but base64 encoded</source>
        <translation>som ovan men kodad med base64</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="46"/>
        <source>command outputs structured variables to be used for button visualization in form of:</source>
        <translation>kommandot matar ut strukturerade variabler som ska användas för knappvisualisering i form av:</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="47"/>
        <source>name1:base64value1 name2:base64value2  ...</source>
        <translation>namn:base64värde1 namn2:base64värde2    ...</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="48"/>
        <source>Handled names are:</source>
        <translation>Hanterade namn är:</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="49"/>
        <source>string to be used as text of the button</source>
        <translation>sträng som ska användas som text för knapp</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="50"/>
        <source>icon to be shown in the button, in the same form as explained before</source>
        <translation>ikon som ska visas i knapp, i samma form som förklarats tidigare</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="51"/>
        <source>string to be used as tooltip of the button</source>
        <translation>sträng som ska användas som verktygstips för knapp</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="52"/>
        <source>All values should be encoded in base64</source>
        <translation>Alla värden ska vara kodade i base64</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="53"/>
        <source>Example of script generating structured output:</source>
        <translation>Exempel på skript som genererar strukturerad utdata:</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="54"/>
        <source>My Text</source>
        <translation>Min text</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="55"/>
        <source>my_image</source>
        <translation>min_bild</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="56"/>
        <source>My Tooltip</source>
        <translation>Mitt verktygstips</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="63"/>
        <source>Text only</source>
        <translation>Text endast</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="64"/>
        <source>Icon only</source>
        <translation>Ikon endast</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="65"/>
        <source>Structured</source>
        <translation>Strukturerad</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="268"/>
        <source>Select Icon File</source>
        <translation>Välj ikonfil</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="268"/>
        <source>Images (*.png *.svg *.xpm *.jpg)</source>
        <translation>Bilder (*.png *.svg *.xpm *.jpg)</translation>
    </message>
</context>
</TS>
